# Set version
from pkg_resources import get_distribution
__version__ = get_distribution('qtstylish').version

# Imports
from qtstylish.qtstylish import dark, light, ThemeSwitcher
from qtstylish.demo_widget import DemoWidget
from qtstylish.modern_window import ModernWindow

__all__ = ["dark", "light", "ThemeSwitcher",
           "DemoWidget", "ModernWindow", "__version__"]



import math
from PIL import Image
from qtstylish.demo_widget import DemoWidget
import sys
import os
from PyQt5 import QtWidgets, QtGui, QtCore
import qtstylish


def make_collage(image_paths, output_path, margin=10):
    """
    Make a collage image with a width equal to `width` from `images` and save to `filename`.
    """
    print(image_paths)
    images = [Image.open(path) for path in image_paths]

    col_count = round(math.sqrt(len(images)))
    row_count = math.ceil(len(images) / col_count)

    print(row_count, col_count)
    image_height = max([image.height for image in images])
    image_width = max([image.width for image in images])
    background_size = (image_width * col_count, image_height * row_count)
    background = Image.new(
        'RGBA', background_size, (255, 255, 255, 0))
    print(background_size)
    for row in range(row_count):
        for col in range(col_count):
            try:
                image = images[col + row * col_count]
                offset = (col * (image_width + margin),
                          row * (image_height + margin))
                print(offset)
                background.paste(image, offset)
            except IndexError:
                break
    background.save(output_path)
    return True


if __name__ == '__main__':
    app = QtWidgets.QApplication([])
    app.setStyle(QtWidgets.QStyleFactory.create("fusion"))
    for theme in ['light', 'dark']:

        screenshots_dir = os.path.abspath(f'./screenshots/{theme}')
        collage_path = f'./screenshots/{theme}.png'
        os.makedirs(screenshots_dir, exist_ok=True)
        example = DemoWidget()
        if theme == 'light':
            example.setStyleSheet(qtstylish.light())
        elif theme == 'dark':
            example.setStyleSheet(qtstylish.dark())

        example.setFixedSize(900, 650)

        for ix, tab_name in enumerate(
                ['Buttons', 'Controls', 'Inputs', 'Displays', 'Containers', 'Tabs', 'Widgets', 'Main Window']):
            example.tabs.setCurrentIndex(ix)
            example.resize(750, 1000)
            pixmap = example.grab()
            save_path = os.path.abspath(os.path.join(
                screenshots_dir, tab_name + '.png'))
            print(save_path)
            pixmap.save(save_path, 'png')
        # Make collage

        image_paths = [os.path.abspath(os.path.join(
            screenshots_dir, path)) for path in os.listdir(screenshots_dir)]
        make_collage(image_paths, collage_path)



from qtstylish import DemoWidget, ThemeSwitcher, ModernWindow
import sys
from PyQt5 import QtWidgets, QtGui, QtCore
import os

if __name__ == '__main__':
    app = QtWidgets.QApplication(sys.argv)

    dw = DemoWidget()
    dw.setStyle(QtWidgets.QStyleFactory.create("Fusion"))

    ts = ThemeSwitcher(dw, hot_reload=True)
    mw = ModernWindow(ts)
    ts.widget_to_style = mw
    mw.resize(1000, 700)
    mw.show()
    app.exec_()



from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtCore import Qt

from PyQt5.QtWidgets import *

try:
    from pandasgui import show
    from pandasgui.datasets import pokemon, mi_manufacturing
except:
    pass


class DemoWidget(QtWidgets.QWidget):
    def __init__(self):
        super().__init__()

        self.tabs = QTabWidget()
        layout = QVBoxLayout()
        layout.addWidget(self.tabs)
        self.setLayout(layout)

        #########################
        # Reusable stuff
        icon = self.style().standardIcon(QtWidgets.QStyle.SP_VistaShield)
        scene = QGraphicsScene()
        scene.addEllipse(10, 10, 100, 100, QtGui.QPen(
            Qt.black), QtGui.QBrush(Qt.red))
        scene.addRect(-10, -10, 50, 50, QtGui.QPen(Qt.black),
                      QtGui.QBrush(Qt.green))

        #########################
        # Buttons (QRadioButton, QCheckBox, QPushButton, QToolButton, QCommandLinkButton)
        buttons_layout = QGridLayout()
        buttons_container = QWidget()
        buttons_container.setLayout(buttons_layout)
        self.tabs.addTab(buttons_container, "Buttons")
        buttons_layout.addWidget(QLabel("Enabled"), 0, 1)
        buttons_layout.addWidget(QLabel("Disabled"), 0, 2)
        buttons_layout.setRowStretch(999, 1)

        row = 1
        # QRadioButton (checked)
        buttons_layout.addWidget(QLabel("QRadioButton (checked)"), row, 0)

        x = QRadioButton("Lorem Ipsum")
        x.setEnabled(True)
        x.setChecked(True)
        buttons_layout.addWidget(x, row, 1)

        x = QRadioButton("Lorem Ipsum")
        x.setEnabled(False)
        x.setChecked(True)
        buttons_layout.addWidget(x, row, 2)

        row += 1
        # QRadioButton (unchecked)
        buttons_layout.addWidget(QLabel("QRadioButton (unchecked)"), row, 0)

        x = QRadioButton("Lorem Ipsum")
        x.setEnabled(True)
        x.setChecked(False)
        buttons_layout.addWidget(x, row, 1)

        x = QRadioButton("Lorem Ipsum")
        x.setEnabled(False)
        x.setChecked(False)
        buttons_layout.addWidget(x, row, 2)

        row += 1
        # QCheckBox (checked)
        buttons_layout.addWidget(QLabel("QCheckBox (checked)"), row, 0)

        x = QCheckBox("Lorem Ipsum")
        x.setEnabled(True)
        x.setChecked(True)
        buttons_layout.addWidget(x, row, 1)

        x = QCheckBox("Lorem Ipsum")
        x.setEnabled(False)
        x.setChecked(True)
        buttons_layout.addWidget(x, row, 2)

        row += 1
        # QCheckBox (unchecked)
        buttons_layout.addWidget(QLabel("QCheckBox (unchecked)"), row, 0)

        x = QCheckBox("Lorem Ipsum")
        x.setEnabled(True)
        x.setChecked(False)
        buttons_layout.addWidget(x, row, 1)

        x = QCheckBox("Lorem Ipsum")
        x.setEnabled(False)
        x.setChecked(False)
        buttons_layout.addWidget(x, row, 2)

        row += 1
        # QCheckBox (tristate)
        buttons_layout.addWidget(QLabel("QCheckBox (tristate)"), row, 0)

        x = QCheckBox("Lorem Ipsum")
        x.setEnabled(True)
        x.setCheckState(Qt.PartiallyChecked)
        buttons_layout.addWidget(x, row, 1)

        x = QCheckBox("Lorem Ipsum")
        x.setEnabled(False)
        x.setCheckState(Qt.PartiallyChecked)
        buttons_layout.addWidget(x, row, 2)

        row += 1
        # QPushButton
        buttons_layout.addWidget(QLabel("QPushButton"), row, 0)

        x = QPushButton("Lorem Ipsum")
        x.setEnabled(True)
        buttons_layout.addWidget(x, row, 1)

        x = QPushButton("Lorem Ipsum")
        x.setEnabled(False)
        buttons_layout.addWidget(x, row, 2)

        row += 1
        # QPushButton (checkable)
        buttons_layout.addWidget(QLabel("QPushButton (checkable)"), row, 0)

        x = QPushButton("Lorem Ipsum")
        x.setEnabled(True)
        x.setCheckable(True)
        x.setChecked(True)
        buttons_layout.addWidget(x, row, 1)

        x = QPushButton("Lorem Ipsum")
        x.setEnabled(False)
        x.setCheckable(True)
        x.setChecked(True)
        buttons_layout.addWidget(x, row, 2)

        #########################
        # Controls (QComboBox, QDial, QSlider, QScrollBar)

        controls_layout = QGridLayout()
        controls_container = QWidget()
        controls_container.setLayout(controls_layout)
        self.tabs.addTab(controls_container, "Controls")
        controls_layout.addWidget(QLabel("Enabled"), 0, 1)
        controls_layout.addWidget(QLabel("Disabled"), 0, 2)
        controls_layout.setRowStretch(999, 1)

        row = 1
        # QComboBox
        controls_layout.addWidget(QLabel("QComboBox"), row, 0)

        x = QComboBox()
        x.setEnabled(True)
        x.addItem("Lorem Ipsum 1")
        x.addItem("Lorem Ipsum 2")
        x.addItem(icon, "Lorem Ipsum 3 (icon)")
        controls_layout.addWidget(x, row, 1)

        x = QComboBox()
        x.setEnabled(False)
        x.addItem("Lorem Ipsum 1")
        x.addItem("Lorem Ipsum 2")
        x.addItem(icon, "Lorem Ipsum 3 (icon)")
        controls_layout.addWidget(x, row, 2)

        row += 1
        # QComboBox (editable)
        controls_layout.addWidget(QLabel("QComboBox (editable)"), row, 0)

        x = QComboBox()
        x.setEnabled(True)
        x.setEditable(True)
        x.addItem("Lorem Ipsum 1")
        x.addItem("Lorem Ipsum 2")
        x.addItem(icon, "Lorem Ipsum 3 (icon)")
        controls_layout.addWidget(x, row, 1)

        x = QComboBox()
        x.setEnabled(False)
        x.setEditable(True)
        x.addItem("Lorem Ipsum 1")
        x.addItem("Lorem Ipsum 2")
        x.addItem(icon, "Lorem Ipsum 3 (icon)")
        controls_layout.addWidget(x, row, 2)

        row += 1
        # QDial
        controls_layout.addWidget(QLabel("QDial"), row, 0)

        x = QDial()
        x.setEnabled(True)
        controls_layout.addWidget(x, row, 1)

        x = QDial()
        x.setEnabled(False)
        controls_layout.addWidget(x, row, 2)

        row += 1
        # QSlider (horizontal)
        controls_layout.addWidget(QLabel("QSlider (horizontal)"), row, 0)

        x = QSlider()
        x.setEnabled(True)
        x.setOrientation(Qt.Horizontal)
        x.setValue(50)
        controls_layout.addWidget(x, row, 1)

        x = QSlider()
        x.setEnabled(False)
        x.setOrientation(Qt.Horizontal)
        x.setValue(50)
        controls_layout.addWidget(x, row, 2)

        row += 1
        # QSlider (vertical)
        controls_layout.addWidget(QLabel("QSlider (vertical)"), row, 0)

        x = QSlider()
        x.setEnabled(True)
        x.setOrientation(Qt.Vertical)
        x.setValue(50)
        controls_layout.addWidget(x, row, 1)

        x = QSlider()
        x.setEnabled(False)
        x.setOrientation(Qt.Vertical)
        x.setValue(50)
        controls_layout.addWidget(x, row, 2)

        row += 1
        # QScrollBar (horizontal)
        controls_layout.addWidget(QLabel("QScrollBar (horizontal)"), row, 0)

        x = QScrollBar()
        x.setEnabled(True)
        x.setOrientation(Qt.Horizontal)
        x.setValue(50)
        controls_layout.addWidget(x, row, 1)

        x = QScrollBar()
        x.setEnabled(False)
        x.setOrientation(Qt.Horizontal)
        x.setValue(50)
        controls_layout.addWidget(x, row, 2)

        row += 1
        # QScrollBar (vertical)
        controls_layout.addWidget(QLabel("QScrollBar (vertical)"), row, 0)

        x = QScrollBar()
        x.setEnabled(True)
        x.setOrientation(Qt.Vertical)
        x.setValue(50)
        controls_layout.addWidget(x, row, 1)

        x = QScrollBar()
        x.setEnabled(False)
        x.setOrientation(Qt.Vertical)
        x.setValue(50)
        controls_layout.addWidget(x, row, 2)

        #########################
        # Inputs (QLineEdit, QTextEdit, QPlainTextEdit, QSpinBox, QDoubleSpinBox, TimeEdit, DateEdit, TimeDateEdit)

        inputs_layout = QGridLayout()
        inputs_container = QWidget()
        inputs_container.setLayout(inputs_layout)
        self.tabs.addTab(inputs_container, "Inputs")
        inputs_layout.addWidget(QLabel("Enabled"), 0, 1)
        inputs_layout.addWidget(QLabel("Disabled"), 0, 2)
        inputs_layout.setRowStretch(999, 1)

        row = 1
        # QLineEdit
        inputs_layout.addWidget(QLabel("QLineEdit"), row, 0)

        x = QLineEdit("Lorem Ipsum")
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QLineEdit("Lorem Ipsum")
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QTextEdit
        inputs_layout.addWidget(QLabel("QTextEdit"), row, 0)

        x = QTextEdit("<h3>Lorem Ipsum</h3>")
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QTextEdit("<h3>Lorem Ipsum<h3>")
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QPlainTextEdit
        inputs_layout.addWidget(QLabel("QPlainTextEdit"), row, 0)

        x = QPlainTextEdit("Lorem Ipsum")
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QPlainTextEdit("Lorem Ipsum")
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QSpinBox
        inputs_layout.addWidget(QLabel("QSpinBox"), row, 0)

        x = QSpinBox()
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QSpinBox()
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QDoubleSpinBox
        inputs_layout.addWidget(QLabel("QDoubleSpinBox"), row, 0)

        x = QDoubleSpinBox()
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QDoubleSpinBox()
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QTimeEdit
        inputs_layout.addWidget(QLabel("QTimeEdit"), row, 0)

        x = QTimeEdit()
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QTimeEdit()
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QDateEdit
        inputs_layout.addWidget(QLabel("QDateEdit"), row, 0)

        x = QDateEdit()
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QDateEdit()
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        row += 1
        # QDateTimeEdit
        inputs_layout.addWidget(QLabel("QDateTimeEdit"), row, 0)

        x = QDateTimeEdit()
        x.setEnabled(True)
        inputs_layout.addWidget(x, row, 1)

        x = QDateTimeEdit()
        x.setEnabled(False)
        inputs_layout.addWidget(x, row, 2)

        #########################
        # Displays (QLabel, QTextBrowser, QGraphicsView, QLCDNumber, QProgressBar, QLine)

        displays_layout = QGridLayout()
        displays_container = QWidget()
        displays_container.setLayout(displays_layout)
        self.tabs.addTab(displays_container, "Displays")
        displays_layout.addWidget(QLabel("Enabled"), 0, 1)
        displays_layout.addWidget(QLabel("Disabled"), 0, 2)
        displays_layout.setRowStretch(999, 1)

        row = 1
        # QLabel
        displays_layout.addWidget(QLabel("QLabel"), row, 0)

        x = QLabel("Lorem Ipsum")
        x.setEnabled(True)
        displays_layout.addWidget(x, row, 1)

        x = QLabel("Lorem Ipsum")
        x.setEnabled(False)
        displays_layout.addWidget(x, row, 2)

        row += 1
        # QTextBrowser
        displays_layout.addWidget(QLabel("QTextBrowser"), row, 0)

        x = QTextBrowser()
        x.setEnabled(True)
        x.setFixedHeight(100)
        x.setHtml("<h3>Lorem Ipsum<h3>")
        displays_layout.addWidget(x, row, 1)

        x = QTextBrowser()
        x.setEnabled(False)
        x.setFixedHeight(100)
        x.setHtml("<h3>Lorem Ipsum<h3>")
        displays_layout.addWidget(x, row, 2)

        row += 1
        # QGraphicsView
        displays_layout.addWidget(QLabel("QGraphicsView"), row, 0)

        x = QGraphicsView()
        x.setEnabled(True)
        x.setFixedHeight(100)
        x.setScene(scene)
        displays_layout.addWidget(x, row, 1)

        x = QGraphicsView()
        x.setEnabled(False)
        x.setFixedHeight(100)
        x.setScene(scene)
        displays_layout.addWidget(x, row, 2)

        row += 1
        # QLCDNumber
        displays_layout.addWidget(QLabel("QLCDNumber"), row, 0)

        x = QLCDNumber()
        x.setEnabled(True)
        x.display(12345.6789)
        displays_layout.addWidget(x, row, 1)

        x = QLCDNumber()
        x.setEnabled(False)
        x.display(12345.6789)
        displays_layout.addWidget(x, row, 2)

        row += 1
        # QProgressBar
        displays_layout.addWidget(QLabel("QProgressBar"), row, 0)

        x = QProgressBar()
        x.setEnabled(True)
        x.setValue(50)
        displays_layout.addWidget(x, row, 1)

        x = QProgressBar()
        x.setEnabled(False)
        x.setValue(50)
        displays_layout.addWidget(x, row, 2)

        row += 1
        # QCalendarWidget
        displays_layout.addWidget(QLabel("QCalendarWidget"), row, 0)

        x = QCalendarWidget()
        x.setEnabled(True)
        displays_layout.addWidget(x, row, 1)

        x = QCalendarWidget()
        x.setEnabled(False)
        displays_layout.addWidget(x, row, 2)

        #########################
        # Containers

        containers_layout = QGridLayout()
        containers_container = QWidget()
        containers_container.setLayout(containers_layout)
        self.tabs.addTab(containers_container, "Containers")
        containers_layout.addWidget(QLabel("Enabled"), 0, 1)
        containers_layout.addWidget(QLabel("Disabled"), 0, 2)
        containers_layout.setRowStretch(999, 1)

        row = 1
        # QScrollArea
        containers_layout.addWidget(QLabel("QScrollArea"), row, 0)

        x = QScrollArea()
        x.setEnabled(True)
        x.setFixedSize(250, 150)
        x.setWidget(QLabel(("Lorem Ipsum " * 5 + "\n") * 20))
        containers_layout.addWidget(x, row, 1)

        x = QScrollArea()
        x.setEnabled(False)
        x.setFixedSize(250, 150)
        x.setWidget(QLabel(("Lorem Ipsum " * 5 + "\n") * 20))
        containers_layout.addWidget(x, row, 2)

        row += 1
        # QFrame
        containers_layout.addWidget(QLabel("QFrame"), row, 0)

        x = QLabel("Lorem Ipsum")
        x.setEnabled(True)
        x.setGeometry(QtCore.QRect(89, 403, 194, 40))
        x.setFrameShape(QtWidgets.QFrame.StyledPanel)
        x.setFrameShadow(QtWidgets.QFrame.Raised)
        containers_layout.addWidget(x, row, 1)

        x = QLabel("Lorem Ipsum")
        x.setEnabled(False)
        x.setFrameShape(QtWidgets.QFrame.StyledPanel)
        x.setFrameShadow(QtWidgets.QFrame.Raised)
        containers_layout.addWidget(x, row, 2)

        row += 1
        # QGroupBox
        containers_layout.addWidget(QLabel("QGroupBox"), row, 0)

        x = QGroupBox()
        x.setEnabled(True)
        l = QVBoxLayout()
        l.addWidget(QLabel("Lorem Ipsum"))
        x.setLayout(l)
        x.setTitle("Lorem Ipsum")
        containers_layout.addWidget(x, row, 1)

        x = QGroupBox()
        x.setEnabled(False)
        l = QVBoxLayout()
        l.addWidget(QLabel("Lorem Ipsum"))
        x.setLayout(l)
        x.setTitle("Lorem Ipsum")
        containers_layout.addWidget(x, row, 2)

        row += 1
        # QToolBox
        containers_layout.addWidget(QLabel("QToolBox"), row, 0)

        x = QToolBox()
        x.setEnabled(True)
        x.addItem(QLabel("Lorem Ipsum 1"), "Lorem Ipsum 1")
        x.addItem(QLabel("Lorem Ipsum 2"), "Lorem Ipsum 2")
        x.addItem(QLabel("Lorem Ipsum 3 (icon)"), icon, "Lorem Ipsum 3")
        containers_layout.addWidget(x, row, 1)

        x = QToolBox()
        x.setEnabled(False)
        x.addItem(QLabel("Lorem Ipsum 1"), "Lorem Ipsum 1")
        x.addItem(QLabel("Lorem Ipsum 2"), "Lorem Ipsum 2")
        x.addItem(QLabel("Lorem Ipsum 3"), icon, "Lorem Ipsum 3 (icon)")
        containers_layout.addWidget(x, row, 2)

        row += 1
        # QSplitter
        containers_layout.addWidget(QLabel("QSplitter"), row, 0)

        x = QSplitter()
        x.setEnabled(True)
        x.addWidget(QLabel("Lorem Ipsum 1"))
        x.addWidget(QLabel("Lorem Ipsum 2"))
        x.setFixedHeight(50)
        containers_layout.addWidget(x, row, 1)

        x = QSplitter()
        x.setEnabled(False)
        x.addWidget(QLabel("Lorem Ipsum 1"))
        x.addWidget(QLabel("Lorem Ipsum 2"))
        x.setFixedHeight(50)
        containers_layout.addWidget(x, row, 2)

        row += 1
        # QStackedWidget
        containers_layout.addWidget(QLabel("QStackedWidget"), row, 0)

        x = QStackedWidget()
        x.setEnabled(True)
        x.addWidget(QLabel("Lorem Ipsum 1"))
        x.addWidget(QLabel("Lorem Ipsum 2"))
        containers_layout.addWidget(x, row, 1)

        x = QStackedWidget()
        x.setEnabled(False)
        x.addWidget(QLabel("Lorem Ipsum 1"))
        x.addWidget(QLabel("Lorem Ipsum 2"))
        containers_layout.addWidget(x, row, 2)

        row += 1
        # QWidget
        containers_layout.addWidget(QLabel("QWidget"), row, 0)

        x = QWidget()
        x.setEnabled(True)
        QLabel("Lorem Ipsum", x)
        containers_layout.addWidget(x, row, 1)

        x = QWidget()
        x.setEnabled(False)
        QLabel("Lorem Ipsum", x)
        containers_layout.addWidget(x, row, 2)

        #########################
        # Tabs (QTabWidget)

        tabs_layout = QGridLayout()
        tabs_container = QWidget()
        tabs_container.setLayout(tabs_layout)
        self.tabs.addTab(tabs_container, "Tabs")
        tabs_layout.addWidget(QLabel("Enabled"), 0, 1)
        tabs_layout.addWidget(QLabel("Disabled"), 0, 2)
        tabs_layout.setRowStretch(999, 1)

        row = 1
        # QTabWidget (North)
        tabs_layout.addWidget(QLabel("QTabWidget (North)"), row, 0)

        x = QTabWidget()
        x.setEnabled(True)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.North)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 1)

        x = QTabWidget()
        x.setEnabled(False)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.North)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 2)

        row += 1
        # QTabWidget (West)
        tabs_layout.addWidget(QLabel("QTabWidget (West)"), row, 0)

        x = QTabWidget()
        x.setEnabled(True)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.West)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 1)

        x = QTabWidget()
        x.setEnabled(False)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.West)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 2)

        row += 1
        # QTabWidget (South)
        tabs_layout.addWidget(QLabel("QTabWidget (South)"), row, 0)

        x = QTabWidget()
        x.setEnabled(True)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.South)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 1)

        x = QTabWidget()
        x.setEnabled(False)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.South)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 2)

        row += 1
        # QTabWidget (East)
        tabs_layout.addWidget(QLabel("QTabWidget (East)"), row, 0)

        x = QTabWidget()
        x.setEnabled(True)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.East)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 1)

        x = QTabWidget()
        x.setEnabled(False)
        x.setTabsClosable(True)
        x.setTabPosition(QTabWidget.TabPosition.East)
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 1")
        x.addTab(QLabel(("Lorem Ipsum " * 2 + "\n") * 4), "Tab 2")
        tabs_layout.addWidget(x, row, 2)

        #########################
        # Widgets (QTreeWidget, QListWidget, QTableWidget)

        widgets_layout = QGridLayout()
        widgets_container = QWidget()
        widgets_container.setLayout(widgets_layout)
        self.tabs.addTab(widgets_container, "Widgets")
        widgets_layout.addWidget(QLabel("Enabled"), 0, 1)
        widgets_layout.addWidget(QLabel("Disabled"), 0, 2)
        widgets_layout.setRowStretch(999, 1)

        row = 1
        # QTableWidget
        widgets_layout.addWidget(QLabel("QTableWidget"), row, 0)

        x = QTableWidget()
        x.setAlternatingRowColors(True)
        x.setEnabled(True)
        x.setSortingEnabled(True)
        x.setRowCount(20)
        x.setColumnCount(20)
        for tr in range(20):
            for tc in range(20):
                x.setItem(tr, tc, QTableWidgetItem(f"Item-{tr}-{tc}"))
        item = QTableWidgetItem("Checkable")
        item.setCheckState(Qt.Checked)
        x.setItem(0, 0, item)
        widgets_layout.addWidget(x, row, 1)

        x = QTableWidget()
        x.setAlternatingRowColors(True)
        x.setEnabled(False)
        x.setSortingEnabled(True)
        x.setRowCount(20)
        x.setColumnCount(20)
        for tr in range(20):
            for tc in range(20):
                x.setItem(tr, tc, QTableWidgetItem(f"Item-{tr}-{tc}"))
        item = QTableWidgetItem("Checkable")
        item.setCheckState(Qt.Checked)
        x.setItem(0, 0, item)
        widgets_layout.addWidget(x, row, 2)

        row += 1
        # QTreeWidget
        widgets_layout.addWidget(QLabel("QTreeWidget"), row, 0)

        x = QTreeWidget()
        x.setEnabled(True)
        x.setHeaderLabels(['1', '2'])
        for a in range(10):
            item = QTreeWidgetItem(x, [f"Col1 Item-{a}", f"Col2 Item-{a}"])
            for b in range(5):
                QTreeWidgetItem(
                    item, [f"Col1 Item-{a}-{b}", f"Col2 Item-{a}-{b}"])
        x.itemAt(0, 0).setCheckState(0, Qt.Checked)
        widgets_layout.addWidget(x, row, 1)

        x = QTreeWidget()
        x.setEnabled(False)
        x.setHeaderLabels(['1', '2'])
        for a in range(10):
            item = QTreeWidgetItem(x, [f"Col1 Item-{a}", f"Col2 Item-{a}"])
            for b in range(5):
                QTreeWidgetItem(
                    item, [f"Col1 Item-{a}-{b}", f"Col2 Item-{a}-{b}"])
        x.itemAt(0, 0).setCheckState(0, Qt.Checked)
        widgets_layout.addWidget(x, row, 2)

        row += 1
        # QListWidget
        widgets_layout.addWidget(QLabel("QTreeWidget"), row, 0)

        x = QListWidget()
        x.setEnabled(True)
        for a in range(10):
            x.addItem(f"Item-{a}")
        x.itemAt(0, 0).setCheckState(Qt.Checked)
        for index in range(x.count()):
            item = x.item(index)
            item.setFlags(item.flags() | QtCore.Qt.ItemIsEditable)
        widgets_layout.addWidget(x, row, 1)

        x = QListWidget()
        x.setEnabled(False)
        for a in range(10):
            x.addItem(f"Item-{a}")
        x.itemAt(0, 0).setCheckState(Qt.Checked)
        widgets_layout.addWidget(x, row, 2)

        #########################
        # Main Window

        container = QWidget()
        layout = QVBoxLayout()
        container.setLayout(layout)
        main_window = QMainWindow()
        main_window.setCentralWidget(container)
        self.tabs.addTab(main_window, "Main Window")

        # QStatusBar
        status_bar = QStatusBar()
        status_bar.setEnabled(True)
        status_bar.setToolTip("Status bar tooltip")
        main_window.setStatusBar(status_bar)

        # QToolTip
        x = QPushButton("Hover Me")
        x.setEnabled(True)
        x.setStatusTip("This is text set by .setStatusTip")
        x.setToolTip("This is text set by .setToolTip")
        layout.addWidget(x)

        # QMenu / QMenuBar
        menu: QMenuBar = main_window.menuBar().addMenu('&Menu')

        disabled_menu: QMenuBar = main_window.menuBar().addMenu('&Disabled Menu')
        disabled_menu.setEnabled(False)

        action1 = menu.addAction("Action1")
        action2 = menu.addAction("Action2")
        action3 = menu.addAction(icon, "Action3 (icon)")
        menu.addSeparator()
        submenu = menu.addMenu("Submenu")
        subaction4 = submenu.addAction("Submenu Action 1")
        subaction5 = submenu.addAction("Submenu Action 2")
        subaction6 = submenu.addAction("Submenu Action 3")
        menu.addSection("Advanced")
        action4 = QAction("Action4 (checkable)", menu, checkable=True)
        menu.addAction(action4)
        action5 = QAction("Action5 (checkable)", menu, checkable=True)
        menu.addAction(action5)
        action5.setChecked(True)

        # QToolBar
        toolbar = QToolBar()
        toolbar.addAction(action1)
        toolbar.addAction(action2)
        toolbar.addAction(action3)
        toolbar.addAction(action4)
        toolbar.addAction(action5)
        main_window.addToolBar(toolbar)

        # QToolButton
        # QSizeGrip

        # QDockWidget (North tabs)
        main_window.dock1 = QtWidgets.QDockWidget("One")
        main_window.dock2 = QtWidgets.QDockWidget("Two")
        main_window.dock3 = QtWidgets.QDockWidget("Three")
        main_window.content1 = QtWidgets.QWidget()
        main_window.content1.setStyleSheet("background-color:#330000;")
        main_window.content1.setMinimumSize(QtCore.QSize(50, 50))
        main_window.content2 = QtWidgets.QWidget()
        main_window.content2.setStyleSheet("background-color:#770000;")
        main_window.content2.setMinimumSize(QtCore.QSize(50, 50))
        main_window.content3 = QtWidgets.QWidget()
        main_window.content3.setStyleSheet("background-color:#AA0000;")
        main_window.content3.setMinimumSize(QtCore.QSize(50, 50))
        main_window.dock1.setWidget(main_window.content1)
        main_window.dock2.setWidget(main_window.content2)
        main_window.dock3.setWidget(main_window.content3)
        main_window.addDockWidget(Qt.RightDockWidgetArea, main_window.dock1)
        main_window.tabifyDockWidget(main_window.dock1, main_window.dock2)
        main_window.addDockWidget(Qt.RightDockWidgetArea, main_window.dock3)
        main_window.setDockOptions(
            main_window.GroupedDragging | main_window.AllowTabbedDocks | main_window.AllowNestedDocks)
        main_window.setTabPosition(
            Qt.AllDockWidgetAreas, QtWidgets.QTabWidget.North)

        # QDockWidget (South tabs)
        main_window.south_dock1 = QtWidgets.QDockWidget("One")
        main_window.south_dock2 = QtWidgets.QDockWidget("Two")
        main_window.south_dock3 = QtWidgets.QDockWidget("Three")
        main_window.south_content1 = QtWidgets.QWidget()
        main_window.south_content1.setStyleSheet("background-color:#003300;")
        main_window.south_content1.setMinimumSize(QtCore.QSize(50, 50))
        main_window.south_content2 = QtWidgets.QWidget()
        main_window.south_content2.setStyleSheet("background-color:#007700;")
        main_window.south_content2.setMinimumSize(QtCore.QSize(50, 50))
        main_window.south_content3 = QtWidgets.QWidget()
        main_window.south_content3.setStyleSheet("background-color:#00AA00;")
        main_window.south_content3.setMinimumSize(QtCore.QSize(50, 50))
        main_window.south_dock1.setWidget(main_window.south_content1)
        main_window.south_dock2.setWidget(main_window.south_content2)
        main_window.south_dock3.setWidget(main_window.south_content3)
        main_window.addDockWidget(
            Qt.BottomDockWidgetArea, main_window.south_dock1)
        main_window.tabifyDockWidget(
            main_window.south_dock1, main_window.south_dock2)
        main_window.addDockWidget(
            Qt.BottomDockWidgetArea, main_window.south_dock3)
        main_window.setDockOptions(
            main_window.GroupedDragging | main_window.AllowTabbedDocks | main_window.AllowNestedDocks)
        main_window.setTabPosition(
            Qt.BottomDockWidgetArea, QtWidgets.QTabWidget.South)

        #########################
        # Modals

        # QMessageBox
        # QDialog
        # QDialogButtonBox

        #########################
        # Temp

        try:
            self.gui = show(pokemon, mi_manufacturing, settings={
                            'block': False, 'theme': 'classic'})
            self.tabs.addTab(self.gui, "PandasGUI")
        except:
            pass


if __name__ == "__main__":
    app = QtWidgets.QApplication([])
    example = DemoWidget()
    example.show()
    app.exec_()



import os
import sys
from PyQt5 import QtWidgets
import qtstylish

sys.path.append(os.path.dirname(__file__))
dirname = os.path.dirname(__file__)

DARK = None
LIGHT = None
with open(os.path.join(dirname, "compiled/dark.qss")) as f:
    DARK = f.read()
with open(os.path.join(dirname, "compiled/light.qss")) as f:
    LIGHT = f.read()


# Return QSS stylesheet for dark theme
def dark(hot_reload=False):
    from compiled import qtstylish_rc
    if hot_reload:
        compile()
    return DARK


# Return QSS stylesheet for light theme
def light(hot_reload=False):
    from compiled import qtstylish_rc
    if hot_reload:
        compile()
    return LIGHT


def compile():
    import qtsass
    # Compile SCSS into QSS
    qtsass.compile_filename(os.path.join(dirname, "stylesheets/dark.scss"),
                            os.path.join(dirname, "compiled/dark.qss"))
    qtsass.compile_filename(os.path.join(dirname, "stylesheets/light.scss"),
                            os.path.join(dirname, "compiled/light.qss"))
    # Compile resources defined by style.qrc into a python module
    os.system(f"pyrcc5 {dirname}/stylesheets/main.qrc -o {dirname}/compiled/qtstylish_rc.py")
    # This part is for hot reload
    with open(os.path.join(dirname, "compiled/dark.qss")) as f:
        global DARK
        DARK = f.read()
    with open(os.path.join(dirname, "compiled/light.qss")) as f:
        global LIGHT
        LIGHT = f.read()


class ThemeSwitcher(QtWidgets.QWidget):
    def __init__(self, contents, widget_to_style=None, hot_reload=False):
        super().__init__()

        if widget_to_style is None:
            self.widget_to_style = self
        else:
            self.widget_to_style = widget_to_style

        layout = QtWidgets.QVBoxLayout()
        btn_layout = QtWidgets.QHBoxLayout()

        btn = QtWidgets.QPushButton("Unstyled")
        btn.clicked.connect(lambda: self.widget_to_style.setStyleSheet(""))
        btn_layout.addWidget(btn)

        btn = QtWidgets.QPushButton("Light")
        btn.clicked.connect(lambda: self.widget_to_style.setStyleSheet(qtstylish.light(hot_reload=hot_reload)))
        btn_layout.addWidget(btn)

        btn = QtWidgets.QPushButton("Dark")
        btn.clicked.connect(lambda: self.widget_to_style.setStyleSheet(qtstylish.dark(hot_reload=hot_reload)))
        btn_layout.addWidget(btn)

        ##################

        theme_btn_layout = QtWidgets.QHBoxLayout()
        for style in QtWidgets.QStyleFactory().keys():
            btn = QtWidgets.QPushButton(style)
            btn.clicked.connect(lambda _, s=style: [QtWidgets.QApplication.instance().setStyle(QtWidgets.QStyleFactory.create(s)),
                                                    print(f"Setting style to {s}")])
            theme_btn_layout.addWidget(btn)
        layout.addLayout(theme_btn_layout)

        layout.addLayout(btn_layout)
        layout.addWidget(contents)
        self.setLayout(layout)


if __name__ == "__main__":
    compile()



# Aero snap still doesn't work https://bugreports.qt.io/browse/QTBUG-84466


from typing import Union

from PyQt5 import QtWidgets, QtGui, QtCore
from PyQt5.QtCore import Qt


class TitleBarIcon(QtWidgets.QPushButton):
    def __init__(self, text, parent=None):
        super().__init__(text, parent)

        self.setStyleSheet("margin: 0;"
                           "padding: 0px;"
                           "font-size: 24px;"
                           "width: 58px;"
                           "height: 36px;")

        self.setContentsMargins(0, 0, 0, 0)


class CustomTitleBar(QtWidgets.QFrame):
    def __init__(self, window_widget: QtWidgets.QWidget):
        super().__init__(window_widget)

        self.window_widget = window_widget
        self.minimize_button = TitleBarIcon("🗕")
        self.maximize_button = TitleBarIcon("🗖")
        self.exit_button = TitleBarIcon("✕")

        self.minimize_button.clicked.connect(lambda: window_widget.setWindowState(Qt.WindowMinimized))
        self.maximize_button.clicked.connect(lambda: (window_widget.showNormal()
                                                      if window_widget.isMaximized()
                                                      else window_widget.showMaximized()))
        self.exit_button.clicked.connect(window_widget.close)

        self.layout = QtWidgets.QHBoxLayout()
        self.setLayout(self.layout)

        self.layout.addSpacerItem(QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding))
        for widget in [
            self.minimize_button,
            self.maximize_button,
            self.exit_button,
        ]:
            self.layout.addWidget(widget)

        self.setStyleSheet("width: 100%;"
                           "padding: 0;"
                           "margin: 0;")
        self.setContentsMargins(0, 0, 0, 0)
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.setSpacing(0)

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        self.window_widget.windowHandle().startSystemMove()


class ModernWindow(QtWidgets.QWidget):
    gripSize = 6

    def __init__(self, widget: QtWidgets.QWidget):
        super().__init__()

        # Remove window title bar and frame
        self.setWindowFlags(Qt.Window | Qt.FramelessWindowHint)

        self.title_bar = CustomTitleBar(self)
        self.main_widget = widget

        # Set up layout
        self.main_layout = QtWidgets.QVBoxLayout()
        self.main_layout.addWidget(self.title_bar)
        self.main_layout.addWidget(self.main_widget)

        self.main_layout.setContentsMargins(0, 0, 0, 0)
        self.main_layout.setSpacing(0)

        self.grip_layout = QtWidgets.QGridLayout()

        self.grip_layout.addLayout(self.main_layout, 1, 1)
        self.grip_layout.addWidget(EdgeGrip(Qt.TopEdge), 0, 1)
        self.grip_layout.addWidget(EdgeGrip(Qt.RightEdge), 1, 2)
        self.grip_layout.addWidget(EdgeGrip(Qt.BottomEdge), 2, 1)
        self.grip_layout.addWidget(EdgeGrip(Qt.LeftEdge), 1, 0)
        self.grip_layout.addWidget(EdgeGrip(Qt.TopEdge | Qt.LeftEdge), 0, 0)
        self.grip_layout.addWidget(EdgeGrip(Qt.TopEdge | Qt.RightEdge), 0, 2)
        self.grip_layout.addWidget(EdgeGrip(Qt.BottomEdge | Qt.LeftEdge), 2, 0)
        self.grip_layout.addWidget(EdgeGrip(Qt.BottomEdge | Qt.RightEdge), 2, 2)

        self.grip_layout.setContentsMargins(0, 0, 0, 0)
        self.grip_layout.setSpacing(0)
        self.setLayout(self.grip_layout)


class EdgeGrip(QtWidgets.QWidget):
    def __init__(self, edges: Union[Qt.Edges, Qt.Edge], grip_size=6, parent=None):
        QtWidgets.QWidget.__init__(self, parent)
        self.edges = edges
        self.grip_size = grip_size
        # Sides
        if edges == Qt.TopEdge:
            self.setCursor(Qt.SizeVerCursor)
            self.setFixedHeight(self.grip_size)
        elif edges == Qt.RightEdge:
            self.setCursor(Qt.SizeHorCursor)
            self.setFixedWidth(self.grip_size)
        elif edges == Qt.BottomEdge:
            self.setCursor(Qt.SizeVerCursor)
            self.setFixedHeight(self.grip_size)
        elif edges == Qt.LeftEdge:
            self.setCursor(Qt.SizeHorCursor)
            self.setFixedWidth(self.grip_size)
        # Corners
        elif edges == Qt.TopEdge | Qt.LeftEdge:
            self.setCursor(Qt.SizeFDiagCursor)
        elif edges == Qt.TopEdge | Qt.RightEdge:
            self.setCursor(Qt.SizeBDiagCursor)
        elif edges == Qt.BottomEdge | Qt.LeftEdge:
            self.setCursor(Qt.SizeBDiagCursor)
        elif edges == Qt.BottomEdge | Qt.RightEdge:
            self.setCursor(Qt.SizeFDiagCursor)

    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.parent().windowHandle().startSystemResize(self.edges)


if __name__ == "__main__":
    app = QtWidgets.QApplication([])

    main = QtWidgets.QMainWindow()

    content = QtWidgets.QTextEdit("Lorem Ipsum")
    main.setCentralWidget(content)

    window = ModernWindow(main)
    window.resize(900, 900)
    window.show()

    app.exec_()



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf8") as fh:
    long_description = fh.read()

setup(
    name="qtstylish",
    version="0.1.5",
    description="Modern styles for PyQt5.",
    author="Adam Rose",
    author_email="adam.e.rose@hotmail.com",
    url="https://github.com/adamerose/qtstylish",
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
    exclude_package_data={'': ['.gitignore']},
    # Using this instead of MANIFEST.in - https://pypi.org/project/setuptools-git/
    setup_requires=['setuptools-git'],
    install_requires=[
        "PyQt5",
    ],
)
